@@ -24,7 +24,7 @@ __docformat__ = "restructuredtext en"
 modname = "yams"
 
 # release version
-numversion = (0, 48, 0)
+numversion = (0, 49, 3)
 version = ".".join(str(num) for num in numversion)
 
 # license and copyright
@@ -49,7 +49,7 @@ scripts = ["bin/yams-check", "bin/yams-view"]
 install_requires = [
     "setuptools",
     "logilab-common >= 1.9.0",
-    "logilab-database >= 1.11",
+    "python-dateutil",
 ]
 
 classifiers = [
