@@ -18,11 +18,11 @@
 from datetime import time, date
 from yams.buildobjs import EntityType, Datetime, Date, Time
 
-class Datetest(EntityType):
-    dt1 = Datetime(default=u'now')
-    dt2 = Datetime(default=u'today')
-    d1  = Date(default=u'today')
-    d2  = Date(default=date(2007, 12, 11))
-    t1  = Time(default=time(8, 40))
-    t2  = Time(default=time(9, 45))
 
+class Datetest(EntityType):
+    dt1 = Datetime(default="now")
+    dt2 = Datetime(default="today")
+    d1 = Date(default="today")
+    d2 = Date(default=date(2007, 12, 11))
+    t1 = Time(default=time(8, 40))
+    t2 = Time(default=time(9, 45))
