@@ -19,10 +19,14 @@
 from logilab.common.testlib import mock_object
 
 import unittest
+import warnings
 
 from yams.constraints import (
     Attribute,
     BoundaryConstraint,
+    convert_date,
+    convert_datetime,
+    convert_tzdatetime,
     FormatConstraint,
     IntervalBoundConstraint,
     NOW,
@@ -31,12 +35,52 @@ from yams.constraints import (
     StaticVocabularyConstraint,
     TODAY,
     UniqueConstraint,
+    _check_no_error_during_convert,
 )
-from datetime import datetime, date, timedelta
+from datetime import datetime, date, timedelta, timezone
+from dateutil.tz import tzoffset
+
+
+class CheckAndConverttTC(unittest.TestCase):
+    def test_check_no_error_during_convert(self):
+        self.assertTrue(_check_no_error_during_convert("4", int))
+        self.assertFalse(_check_no_error_during_convert("not a int", int))
+
+    def test_convert_date(self):
+        expected = date(1990, 10, 30)
+        dt = datetime(1990, 10, 30, 10)
+        self.assertEqual(convert_date(expected), expected)
+        self.assertEqual(convert_date("1990-10-30"), expected)
+        self.assertEqual(convert_date(dt), expected)
+
+        with self.assertRaises(ValueError):
+            convert_date("not a date")
+
+    def test_convert_datetime(self):
+        expected = datetime(1990, 10, 30, 10)
+        self.assertEqual(convert_datetime(expected), expected)
+        self.assertEqual(convert_datetime("1990-10-30 10"), expected)
+
+        example_date = date(1990, 10, 30)
+        self.assertEqual(convert_datetime(example_date), datetime(1990, 10, 30))
+
+        with self.assertRaises(ValueError):
+            convert_datetime("not a datetime")
+
+    def test_convert_tzdatetime_accepts_iso_string(self):
+        central_european_time = tzoffset("CET", 3600)  # UTC+01
+        expected = datetime(1990, 10, 30, 10, tzinfo=central_european_time)
+        self.assertEqual(convert_tzdatetime("1990-10-30T10:00+01"), expected)
+
+    def test_convert_tzdatetime_parses_iso_string_without_tz_as_utc(self):
+        expected = datetime(1990, 10, 30, 9, tzinfo=timezone.utc)
+        with warnings.catch_warnings(record=True) as w:
+            self.assertEqual(convert_tzdatetime("1990-10-30T09:00"), expected)
+        self.assertNotEqual([], w)
+        self.assertIn("Passing a datetime without timezone is deprecated", str(w[0]))
 
 
 class ConstraintTC(unittest.TestCase):
-
     if not hasattr(unittest.TestCase, "subTest"):
         from contextlib import contextmanager
 
