@@ -204,7 +204,6 @@ class autopackage(type):
     def __new__(
         mcs: "Type[autopackage]", name: str, bases: Tuple, classdict: Dict[str, Any]
     ) -> Any:
-
         classdict["package"] = PACKAGE
 
         return super(autopackage, mcs).__new__(mcs, name, bases, classdict)
@@ -262,6 +261,7 @@ class Definition(object, metaclass=autopackage):
 
 # classes used to define relationships within entity type classes ##################
 
+
 # has to be defined before the metadefinition metaclass which "isinstance" this
 # class
 @deprecation.attribute_renamed(old_name="etype", new_name="entity_type", version="0.48")
@@ -271,7 +271,9 @@ class ObjectRelation:
     constraints = MARKER
 
     @deprecation.argument_renamed(old_name="etype", new_name="entity_type", version="0.48")
-    def __init__(self, entity_type: str, override: bool = False, **kwargs) -> None:
+    def __init__(
+        self, entity_type: Union[str, Tuple[str]], override: bool = False, **kwargs
+    ) -> None:
         if self.__class__.__name__ == "ObjectRelation":
             warn(
                 "[yams 0.29] ObjectRelation is deprecated, " "use RelationDefinition subclass",
@@ -285,7 +287,7 @@ class ObjectRelation:
 
         self.package: str = PACKAGE
         self.name: str = "<undefined>"
-        self.entity_type: str = entity_type
+        self.entity_type: Union[str, Tuple[str]] = entity_type
         self.override: bool = override
 
         if self.constraints:
@@ -343,7 +345,6 @@ class AbstractTypedAttribute(SubjectRelation):
         override: bool = False,
         **kwargs,
     ):
-
         # Store metadata
         if metadata is None:
             metadata = {}
@@ -557,7 +558,6 @@ class metadefinition(autopackage):
     def __new__(
         mcs: "Type[metadefinition]", name: str, bases: Tuple, classdict: Dict[str, Any]
     ) -> Any:
-
         # Move (any) relation from the class dict to __relations__ attribute
         relations_list: List = classdict.setdefault("__relations__", [])
         relations: Dict[str, Any] = dict(
@@ -947,8 +947,8 @@ class RelationDefinition(Definition):
     # and the symmetric property.
     # """
 
-    subject: Union[nullobject, str, None] = MARKER
-    object: Union[nullobject, str, None] = MARKER
+    subject: Union[nullobject, str, List[str], None] = MARKER
+    object: Union[nullobject, str, List[str], None] = MARKER
     cardinality: Union[nullobject, str, None] = MARKER
     constraints = MARKER
     symmetric = MARKER
@@ -957,9 +957,9 @@ class RelationDefinition(Definition):
 
     def __init__(
         self,
-        subject: Optional[str] = None,
+        subject: Optional[Union[str, Tuple[str]]] = None,
         name: Optional[str] = None,
-        object: Optional[str] = None,
+        object: Optional[Union[str, Tuple[str]]] = None,
         package: Optional[str] = None,
         **kwargs,
     ) -> None:
