@@ -22,14 +22,16 @@ import decimal
 import operator
 import json
 import datetime
+from dateutil.parser import parse
 import warnings
 
 from typing import Any, Dict, Match, Tuple, Type, Union, Optional, Callable, Sequence, List, cast
 
-from logilab.common.deprecation import class_renamed
+from logilab.common.deprecation import class_renamed, send_warning
+from logilab.common.date import todate, todatetime
 
 import yams
-from yams import BadSchemaDefinition
+from yams import KEYWORD_MAP, BadSchemaDefinition
 from yams.interfaces import IConstraint, IVocabularyConstraint
 import yams.types as yams_types
 
@@ -194,7 +196,6 @@ class UniqueConstraint(BaseConstraint):
         objschema: yams_types.EntitySchema,
         rdef: yams_types.RelationDefinition,
     ) -> None:
-
         if not objschema.final:
             raise BadSchemaDefinition("unique constraint doesn't apply to non " "final entity type")
 
@@ -213,7 +214,6 @@ class SizeConstraint(BaseConstraint):
     def __init__(
         self, max: Optional[int] = None, min: Optional[int] = None, msg: Optional[str] = None
     ) -> None:
-
         super(SizeConstraint, self).__init__(msg)
 
         assert max is not None or min is not None, "No max or min"
@@ -244,7 +244,6 @@ class SizeConstraint(BaseConstraint):
         objschema: yams_types.EntitySchema,
         rdef: yams_types.RelationDefinition,
     ) -> None:
-
         if not objschema.final:
             raise BadSchemaDefinition("size constraint doesn't apply to non " "final entity type")
 
@@ -399,7 +398,6 @@ class BoundaryConstraint(BaseConstraint):
     def __init__(
         self, op: str, boundary: Optional[Union["Attribute", "NOW", "TODAY"]] = None, msg=None
     ) -> None:
-
         super(BoundaryConstraint, self).__init__(msg)
 
         assert op in OPERATORS, op
@@ -416,7 +414,6 @@ class BoundaryConstraint(BaseConstraint):
         objschema: yams_types.EntitySchema,
         rdef: yams_types.RelationDefinition,
     ) -> None:
-
         if not objschema.final:
             raise BadSchemaDefinition("bound constraint doesn't apply to non " "final entity type")
 
@@ -501,7 +498,6 @@ class IntervalBoundConstraint(BaseConstraint):
         objschema: yams_types.EntitySchema,
         rdef: yams_types.RelationDefinition,
     ) -> None:
-
         if not objschema.final:
             raise BadSchemaDefinition(
                 "interval bound constraint doesn't apply" " to non final entity type"
@@ -611,7 +607,6 @@ class StaticVocabularyConstraint(BaseConstraint):
 
 
 class FormatConstraint(StaticVocabularyConstraint):
-
     regular_formats: Tuple[str, ...] = (
         _("text/rest"),
         _("text/markdown"),
@@ -630,7 +625,6 @@ class FormatConstraint(StaticVocabularyConstraint):
         objschema: yams_types.EntitySchema,
         rdef: yams_types.RelationDefinition,
     ) -> None:
-
         if not objschema.final:
             raise BadSchemaDefinition("format constraint doesn't apply to non " "final entity type")
 
@@ -716,6 +710,15 @@ class TODAY:
 # base types checking functions ###############################################
 
 
+def _check_no_error_during_convert(value: Any, convert_method) -> bool:
+    try:
+        convert_method(value)
+    except ValueError:
+        return False
+
+    return True
+
+
 def check_string(eschema, value) -> bool:
     """check value is an unicode string"""
     return isinstance(value, str)
@@ -728,22 +731,12 @@ def check_password(eschema, value) -> bool:
 
 def check_int(eschema, value) -> bool:
     """check value is an integer"""
-    try:
-        int(value)
-    except ValueError:
-        return False
-
-    return True
+    return _check_no_error_during_convert(value, int)
 
 
 def check_float(eschema, value) -> bool:
     """check value is a float"""
-    try:
-        float(value)
-    except ValueError:
-        return False
-
-    return True
+    return _check_no_error_during_convert(value, float)
 
 
 def check_decimal(eschema, value) -> bool:
@@ -771,12 +764,90 @@ def yes(*args, **kwargs) -> bool:
     return True
 
 
+# types converters #############################################################
+def _str_to_datetime(value: str) -> datetime.datetime:
+    try:
+        return parse(value)
+    except ValueError:
+        try:
+            return datetime.datetime.strptime(value, "%Y/%m/%d %H:%M")
+        except ValueError:
+            return datetime.datetime.strptime(value, "%Y/%m/%d")
+
+
+def convert_datetime(value: Union[str, datetime.date, datetime.datetime]) -> datetime.datetime:
+    # Note: use is __class__ since issubclass(datetime, date)
+    if isinstance(value, str):
+        if value in KEYWORD_MAP["Datetime"]:
+            value = KEYWORD_MAP["Datetime"][value]()
+        else:
+            value = _str_to_datetime(value)
+    elif type(value) is datetime.date:
+        value = todatetime(value)
+
+    if type(value) is not datetime.datetime:
+        raise ValueError(f"Impossible to convert {value} to datetime")
+    return value
+
+
+def convert_date(value: Union[str, datetime.date, datetime.datetime]) -> datetime.date:
+    if isinstance(value, str):
+        if value in KEYWORD_MAP["Date"]:
+            value = KEYWORD_MAP["Date"][value]()
+        else:
+            value = _str_to_datetime(value)
+    if isinstance(value, datetime.datetime):
+        value = todate(value)
+    if type(value) is not datetime.date:
+        raise ValueError(f"Impossible to convert {value} to date")
+    return value
+
+
+def convert_tzdatetime(value: Union[str, datetime.datetime, datetime.date]) -> datetime.datetime:
+    if isinstance(value, str):
+        if value in KEYWORD_MAP["TZDatetime"]:
+            value = KEYWORD_MAP["TZDatetime"][value]()
+        else:
+            value = _str_to_datetime(value)
+    # Note: use is __class__ since issubclass(datetime, date)
+    if type(value) is datetime.date:
+        value = todatetime(value)
+    if type(value) is not datetime.datetime:
+        raise ValueError(f"Impossible to convert {value} to tzdatetime")
+    elif not hasattr(value, "tzinfo") or value.tzinfo is None:
+        value = value.replace(tzinfo=datetime.timezone.utc)
+        send_warning(
+            "Passing a datetime without timezone is deprecated and will "
+            "be disallowed in version 1.0.0. "
+            "For now, datetime without timezone are considered as UTC",
+            DeprecationWarning,
+            {},
+            stacklevel=14,
+        )
+    return value
+
+
+def check_date(eschema, value: Any) -> bool:
+    """Check value is date"""
+    return _check_no_error_during_convert(value, convert_date)
+
+
+def check_datetime(eschema, value: Any) -> bool:
+    """Check value is datetime"""
+    return _check_no_error_during_convert(value, convert_datetime)
+
+
+def check_tzdatetime(eschema, value: Any) -> bool:
+    """Check value is tzdatetime"""
+    return _check_no_error_during_convert(value, convert_tzdatetime)
+
+
 BASE_CHECKERS: yams_types.Checkers = {
-    "Date": yes,
+    "Date": check_date,
     "Time": yes,
-    "Datetime": yes,
-    "TZTime": yes,
-    "TZDatetime": yes,
+    "Datetime": check_datetime,
+    "TZTime": check_tzdatetime,
+    "TZDatetime": check_tzdatetime,
     "Interval": yes,
     "String": check_string,
     "Int": check_int,
@@ -796,6 +867,10 @@ BASE_CONVERTERS: yams_types.Converters = {
     "Float": float,
     "Boolean": bool,
     "Decimal": decimal.Decimal,
+    "Datetime": convert_datetime,
+    "Date": convert_date,
+    "TZDatetime": convert_tzdatetime,
+    "TZTime": convert_tzdatetime,
 }
 
 
